==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/sql_history/translations/sql_history_es_MX.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_MX">
<context>
    <name>HistorySqlStorage</name>
    <message>
        <source>Preparing history database...</source>
        <translation>Preparando la base de datos del historial...</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Historial</translation>
    </message>
    <message>
        <source>Opening database failed. Error message:
%1</source>
        <translation>Error al abrir la base de datos. Mensaje de error:
%1</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>It seems your Qt library does not provide support for selected database. Please install Qt with %1 plugin.</source>
        <translation>Parece que su biblioteca Qt no ofrece soporte para la base de datos seleccionada. Por favor instale Qt con %1 como complemento.</translation>
    </message>
</context>
<context>
    <name>SqlInitializer</name>
    <message>
        <source>Copying history file to new location: %1 ...</source>
        <translation>Copiando el archivo del historial a la nueva ubicación: %1 ...</translation>
    </message>
    <message>
        <source>Unable to copy history file to new location. Check if disk is full.</source>
        <translation>No se puede copiar el archivo del historial a la nueva ubicación. Compruebe si el disco está lleno.</translation>
    </message>
    <message>
        <source>Unable to open database: %1</source>
        <translation>No se puede abrir la base de datos: %1</translation>
    </message>
    <message>
        <source>History file is corrupted, performing recovery...</source>
        <translation>El archivo del historial está dañado, realizando recuperación...</translation>
    </message>
    <message>
        <source>Recovery completed.</source>
        <translation>Recuperación completada.</translation>
    </message>
    <message>
        <source>Recovery failed: %s</source>
        <translation>Error de recuperación: %s</translation>
    </message>
    <message>
        <source>History file is outdated, performing import...</source>
        <translation>El archivo del historial está obsoleta, realizando importación...</translation>
    </message>
    <message>
        <source>Import completed.</source>
        <translation>Importación completada.</translation>
    </message>
    <message>
        <source>Copying completed.</source>
        <translation>Copia completada.</translation>
    </message>
</context>
<context>
    <name>SqlRestore</name>
    <message>
        <source>No error.</source>
        <translation>No hay error.</translation>
    </message>
    <message>
        <source>sqlite3 executable not found.</source>
        <translation>El ejecutable sqlite3 no se ha encontrado. </translation>
    </message>
    <message>
        <source>Invalid invocation of recovery script.</source>
        <translation>Invocación no válida del guión de recuperación.</translation>
    </message>
    <message>
        <source>Unable to read corrupted database.</source>
        <translation>No se puede leer la base de datos dañada.</translation>
    </message>
    <message>
        <source>Unable to create backup file. Disc may be full.</source>
        <translation>No se puede crear un archivo de copia de seguridad. El disco puede estar lleno.</translation>
    </message>
    <message>
        <source>Recovery script not found or not executable.</source>
        <translation>El guión de recuperación no se encuentra o no es ejecutable.</translation>
    </message>
    <message>
        <source>Unknown error during database recovery.</source>
        <translation>Error desconocido durante la recuperación de la base de datos.</translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/sql_history/translations/sql_history_es_MX.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_MX" version="2.1">
<context>
    <name>HistorySqlStorage</name>
    <message>
        <source>Preparing history database...</source>
        <translation>Preparando la base de datos del historial...</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Historial</translation>
    </message>
    <message>
        <source>Opening database failed. Error message:
%1</source>
        <translation>Error al abrir la base de datos. Mensaje de error:
%1</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>It seems your Qt library does not provide support for selected database. Please install Qt with %1 plugin.</source>
        <translation>Parece que su biblioteca Qt no ofrece soporte para la base de datos seleccionada. Por favor instale Qt con %1 como complemento.</translation>
    </message>
</context>
<context>
    <name>SqlInitializer</name>
    <message>
        <source>Copying history file to new location: %1 ...</source>
        <translation>Copiando el archivo del historial a la nueva ubicación: %1 ...</translation>
    </message>
    <message>
        <source>Unable to copy history file to new location. Check if disk is full.</source>
        <translation>No se puede copiar el archivo del historial a la nueva ubicación. Compruebe si el disco está lleno.</translation>
    </message>
    <message>
        <source>Unable to open database: %1</source>
        <translation>No se puede abrir la base de datos: %1</translation>
    </message>
    <message>
        <source>History file is corrupted, performing recovery...</source>
        <translation>El archivo del historial está dañado, realizando recuperación...</translation>
    </message>
    <message>
        <source>Recovery completed.</source>
        <translation>Recuperación completada.</translation>
    </message>
    <message>
        <source>Recovery failed: %s</source>
        <translation>Error de recuperación: %s</translation>
    </message>
    <message>
        <source>History file is outdated, performing import...</source>
        <translation>El archivo del historial está obsoleta, realizando importación...</translation>
    </message>
    <message>
        <source>Import completed.</source>
        <translation>Importación completada.</translation>
    </message>
    <message>
        <source>Copying completed.</source>
        <translation>Copia completada.</translation>
    </message>
</context>
<context>
    <name>SqlRestore</name>
    <message>
        <source>No error.</source>
        <translation>No hay error.</translation>
    </message>
    <message>
        <source>sqlite3 executable not found.</source>
        <translation>El ejecutable sqlite3 no se ha encontrado. </translation>
    </message>
    <message>
        <source>Invalid invocation of recovery script.</source>
        <translation>Invocación no válida del guión de recuperación.</translation>
    </message>
    <message>
        <source>Unable to read corrupted database.</source>
        <translation>No se puede leer la base de datos dañada.</translation>
    </message>
    <message>
        <source>Unable to create backup file. Disc may be full.</source>
        <translation>No se puede crear un archivo de copia de seguridad. El disco puede estar lleno.</translation>
    </message>
    <message>
        <source>Recovery script not found or not executable.</source>
        <translation>El guión de recuperación no se encuentra o no es ejecutable.</translation>
    </message>
    <message>
        <source>Unknown error during database recovery.</source>
        <translation>Error desconocido durante la recuperación de la base de datos.</translation>
    </message>
</context>
</TS>
